@@ -19,7 +19,10 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # or see http://www.r-project.org/Licenses/GPL-2
 
-LKrig.cov <- function(x1, x2 = NULL, LKinfo, C = NA, marginal = FALSE) {
+LKrig.cov <- function(x1, x2 = NULL, LKinfo, C = NA, 
+                      marginal = FALSE, theta=NULL) {
+  # theta is a dummy argument for future development where a 
+  # range parameter is specified directly 
 	PHI1 <- LKrig.basis(x1, LKinfo)
 	# sparse precision matrix for the basis coeficients	
 	Q <- LKrig.precision(LKinfo)
