@@ -1,6 +1,6 @@
 
 
-library(LatticeKrig)
+suppressMessages(library(LatticeKrig))
 options(echo = FALSE)
 test.for.zero.flag <- 1
 ###########################
